@@ -1,10 +1,25 @@
 <?php
+/**
+ * Copyright 2001-2017 Horde LLC (http://www.horde.org/)
+ *
+ * See the enclosed file LICENSE for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
+ *
+ * @author   Robert E. Coyle <robertecoyle@hotmail.com>
+ * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL
+ * @package  Form
+ */
+
 /**
  * This class represents a single form variable that may be rendered as one or
  * more form fields.
  *
- * @author  Robert E. Coyle <robertecoyle@hotmail.com>
- * @package Form
+ * @author    Robert E. Coyle <robertecoyle@hotmail.com>
+ * @category  Horde
+ * @copyright 2001-2017 Horde LLC
+ * @license   http://www.horde.org/licenses/lgpl21 LGPL
+ * @package   Form
  */
 class Horde_Form_Variable {
 
@@ -494,8 +509,9 @@ class Horde_Form_Variable {
         } else {
             $name = $this->varName;
         }
-        $value = $vars->getExists($name, $wasset);
 
+        $value = $vars->get($name);
+        $wasset = $vars->exists($name);
         if (!$wasset) {
             $value = $this->getDefault();
         }
